searchData={"items":[{"type":"module","title":"Tesserax","doc":"Execute commands against the Tesseract OCR Engine.\nAble to either recognize text in images loaded in memory or by providing a path to the image.","ref":"Tesserax.html"},{"type":"function","title":"Tesserax.list_languages/1","doc":"Lists the languages available to tesseract via NIF.\nAccepts path to tessdata (optional).","ref":"Tesserax.html#list_languages/1"},{"type":"function","title":"Examples - Tesserax.list_languages/1","doc":"{:ok, languages} = Tesserax.list_languages()\n\n    {:ok, languages} = Tesserax.list_languages(\"/path/to/tessdata/dir/\")","ref":"Tesserax.html#list_languages/1-examples"},{"type":"function","title":"Tesserax.read_from_file/1","doc":"Runs a command against the NIF with a path to image.","ref":"Tesserax.html#read_from_file/1"},{"type":"function","title":"Examples - Tesserax.read_from_file/1","doc":"{:ok, text} = Tesserax.read_from_file(command)","ref":"Tesserax.html#read_from_file/1-examples"},{"type":"function","title":"Tesserax.read_from_mem/1","doc":"Runs a command against the NIF with the image loaded in memory. Requires the image to be image/png format.","ref":"Tesserax.html#read_from_mem/1"},{"type":"function","title":"Examples - Tesserax.read_from_mem/1","doc":"{:ok, text} = Tesserax.read_from_mem(command)","ref":"Tesserax.html#read_from_mem/1-examples"},{"type":"module","title":"Tesserax.Command","doc":"Builds a command containing information about Tesseract and which image to read.","ref":"Tesserax.Command.html"},{"type":"module","title":"Examples - Tesserax.Command","doc":"command = Tesserax.Command.make_command(\n                image: File.read(\"path/to/image\"), \n                languages: [\"eng\", \"hin\"], \n                tessdata: \"path/to/tessdata/dir\",\n                config: \"path/to/config/file\",\n                psm: psm_value,\n                oem: oem_value\n              )\n\n    Tesserax.Command.image(command)\n    #=> <<...>>\n\n    Tesserax.Command.languages(command)\n    #=> \"eng+hin\"\n\n    Tesserax.Command.tessdata(command)\n    #=> \"path/to/tessdata/dir\"\n\n    Tesserax.Command.config(command)\n    #=> \"path/to/config/file\"\n\n    Tesserax.Command.psm(command)\n    #=> psm_value\n\n    Tesserax.Command.oem(command)\n    #=> oem_value","ref":"Tesserax.Command.html#module-examples"},{"type":"function","title":"Tesserax.Command.config/1","doc":"Fetches the config file path from the command.","ref":"Tesserax.Command.html#config/1"},{"type":"function","title":"Tesserax.Command.image/1","doc":"Fetches image field from the command.","ref":"Tesserax.Command.html#image/1"},{"type":"function","title":"Tesserax.Command.languages/1","doc":"Fetches the languages from the command.","ref":"Tesserax.Command.html#languages/1"},{"type":"function","title":"Tesserax.Command.make_command/2","doc":"Builds a command with available options: `:image`, `:languages`, `:tessdata`, `:config`, `:psm`, `:oem`.\n  * `:image` is either the contents of an image (PNG format), or the path to an image.\n  * `:languages` is the languages that Tesseract should recognize with, either a list or a string.\n  * `:tessdata` is the path to tessdata dir.\n  * `:config` is the path to the config file.\n  * `:psm` is an integer representing Page Segmentation Mode in Tesseract.\n  * `:oem` is an integer representing Ocr Engine Mode in Tesseract.\nIgnores invalid options.","ref":"Tesserax.Command.html#make_command/2"},{"type":"function","title":"Examples - Tesserax.Command.make_command/2","doc":"Tesserax.Command.make_command(\n      image: File.read!(\"path/to/image\"), \n      languages: [\"eng\", \"hin\"], \n      tessdata: \"path/to/tessdata/dir\", \n      config: \"path/to/config/file\", \n      psm: 0, \n      oem: 0\n    )","ref":"Tesserax.Command.html#make_command/2-examples"},{"type":"function","title":"Tesserax.Command.oem/1","doc":"Fetches the oem value from the command.","ref":"Tesserax.Command.html#oem/1"},{"type":"function","title":"Tesserax.Command.prepare_command/1","doc":"Prepares a command. Returns a map with non-`nil` values from the command.","ref":"Tesserax.Command.html#prepare_command/1"},{"type":"function","title":"Tesserax.Command.psm/1","doc":"Fetches the psm value from the command.","ref":"Tesserax.Command.html#psm/1"},{"type":"function","title":"Tesserax.Command.tessdata/1","doc":"Fetches the tessdata path from the command.","ref":"Tesserax.Command.html#tessdata/1"},{"type":"function","title":"Tesserax.Command.values/1","doc":"Fetches all values from a command.","ref":"Tesserax.Command.html#values/1"},{"type":"type","title":"Tesserax.Command.t/0","doc":"","ref":"Tesserax.Command.html#t:t/0"},{"type":"extras","title":"Tesserax","doc":"# Tesserax\n\nAn Elixir application that wraps the [Tesseract OCR Engine](https://github.com/tesseract-ocr/tesseract).\n\nOne utilizes this application by creating commands and feeding them to Tesseract wrappers.\nThe wrapper can be used via `Tesserax.read_from_mem/1` or `Tesserax.read_from_file/1` and needs a `%Tesserax.Command{}` struct as argument.\n`Tesserax.read_from_mem/1` reads text from an image loaded in memory, `Tesserax.read_from_file/1` reads text from the image provided by the image path.\n```elixir\n# Reading text from memory\nTesserax.Command.make_command(\n    image: <<...>>, # image binary data\n    languages: [\"eng\", \"hin\"], \n    tessdata: \"path/to/tessdata/dir\", \n    config: \"path/to/config/file\", \n    psm: 0, \n    oem: 0\n)\n|> Tesserax.read_from_mem()\n\n# Reading text from a file\nTesserax.Command.make_command(\n    image: \"path/to/image\", \n    languages: [\"eng\", \"hin\"], \n    tessdata: \"path/to/tessdata/dir\", \n    config: \"path/to/config/file\", \n    psm: 0, \n    oem: 0\n)\n|> Tesserax.read_from_file()\n```\nAn image loaded in memory needs to be in PNG format.","ref":"readme.html"},{"type":"extras","title":"Installation - Tesserax","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `tesserax` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tesserax, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"},{"type":"extras","title":"See also - Tesserax","doc":"- [tesseract](https://github.com/tesseract-ocr/tesseract)\n- [tesseract-ocr-elixir](https://github.com/dannnylo/tesseract-ocr-elixir).","ref":"readme.html#see-also"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2024 zteln\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}